==> flowable-entitylink-service-6.4.1-sources.jar: org/flowable/entitylink/service/impl/persistence/entity/EntityLinkEntityManager.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.entitylink.service.impl.persistence.entity;

import java.util.List;

import org.flowable.common.engine.impl.persistence.entity.EntityManager;
import org.flowable.entitylink.api.EntityLink;

/**
 * @author Tijs Rademakers
 */
public interface EntityLinkEntityManager extends EntityManager<EntityLinkEntity> {

    List<EntityLink> findEntityLinksByScopeIdAndType(String scopeId, String scopeType, String linkType);
    
    List<EntityLink> findEntityLinksByReferenceScopeIdAndType(String referenceScopeId, String scopeType, String linkType);

    List<EntityLink> findEntityLinksByScopeDefinitionIdAndType(String scopeDefinitionId, String scopeType, String linkType);

    List<EntityLink> deleteScopeEntityLink(String scopeId, String scopeType, String linkType);

    List<EntityLink> deleteScopeDefinitionEntityLink(String scopeDefinitionId, String scopeType, String linkType);

    void deleteEntityLinksByScopeIdAndScopeType(String scopeId, String scopeType);
    
    void deleteEntityLinksByScopeDefinitionIdAndScopeType(String scopeDefinitionId, String scopeType);

}

==> flowable-entitylink-service-6.7.0-sources.jar: org/flowable/entitylink/service/impl/persistence/entity/EntityLinkEntityManager.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.entitylink.service.impl.persistence.entity;

import java.util.List;

import org.flowable.common.engine.impl.persistence.entity.EntityManager;
import org.flowable.entitylink.api.EntityLink;

/**
 * @author Tijs Rademakers
 */
public interface EntityLinkEntityManager extends EntityManager<EntityLinkEntity> {

    List<EntityLink> findEntityLinksByScopeIdAndType(String scopeId, String scopeType, String linkType);

    List<EntityLink> findEntityLinksByRootScopeIdAndRootType(String scopeId, String scopeType);

    List<EntityLink> findEntityLinksWithSameRootScopeForScopeIdAndScopeType(String scopeId, String scopeType, String linkType);
    
    List<EntityLink> findEntityLinksByReferenceScopeIdAndType(String referenceScopeId, String scopeType, String linkType);

    void deleteEntityLinksByScopeIdAndScopeType(String scopeId, String scopeType);

    void deleteEntityLinksByRootScopeIdAndType(String scopeId, String scopeType);
    
}
